@@ -255,8 +255,8 @@ class Converter():
                     if copy_lights:
                         light = light.make_copy()
                     lnp = np.attach_new_node(light)
-                    if isinstance(light, Spotlight):
-                        lnp.set_p(lnp.get_p() - 90)
+                    lnp.set_p(lnp.get_p() - 90)
+                    lnp.set_r(lnp.get_r() - 90)
                     if isinstance(light, Light):
                         root.set_light(lnp)
 
@@ -277,7 +277,7 @@ class Converter():
                                 "Could not find physics mesh ({}) for object ({})"
                                 .format(collision_shape['mesh'], nodeid)
                             )
-                    if 'BP_physics_engine' in gltf_data['extensions']:
+                    if 'extensions' in gltf_data and 'BP_physics_engine' in gltf_data['extensions']:
                         use_bullet = (
                             gltf_data['extensions']['BP_physics_engine']['engine'] == 'bullet'
                         )
@@ -427,6 +427,12 @@ class Converter():
 
         self.textures['__pbr-fallback'] = texture
 
+        texture = Texture('emission-fallback')
+        texture.setup_2d_texture(1, 1, Texture.T_unsigned_byte, Texture.F_rgba)
+        texture.set_clear_color(LColor(0, 0, 0, 0))
+
+        self.textures['__emission-fallback'] = texture
+
         texture = Texture('normal-fallback')
         texture.setup_2d_texture(1, 1, Texture.T_unsigned_byte, Texture.F_rgb)
         texture.set_clear_color(LColor(0.5, 0.5, 1, 1))
@@ -539,6 +545,7 @@ class Converter():
 
         pmat = Material(matname)
         pbr_fallback = {'index': '__pbr-fallback', 'texCoord': 0}
+        emission_fallback = {'index': '__emission-fallback', 'texCoord': 0}
         normal_fallback = {'index': '__normal-fallback', 'texCoord': 0}
         texinfos = []
 
@@ -585,6 +592,12 @@ class Converter():
         # Normal map
         texinfos.append(gltf_mat.get('normalTexture', normal_fallback))
 
+        #Emission map
+        pmat.set_emission(LColor(*gltf_mat.get('emissiveFactor', [0.0, 0.0, 0.0]), w=0.0))
+        texinfos.append(gltf_mat.get('emissiveTexture', emission_fallback))
+        if texinfos[-1]['index'] in self.textures:
+            self.make_texture_srgb(self.textures[texinfos[-1]['index']])
+
         pmat.set_twoside(gltf_mat.get('doubleSided', False))
 
         state = state.set_attrib(MaterialAttrib.make(pmat))
@@ -916,7 +929,7 @@ class Converter():
                 tangent.z,
                 -1.0 if normal.cross(tan0).dot(tan1) < 0 else 1.0
             )
-            tangent_writer.set_data4f(tangent4)
+            tangent_writer.set_data4(tangent4)
 
         geom.set_vertex_data(gvd)
 
@@ -1016,6 +1029,9 @@ class Converter():
             tbtable = TransformBlendTable()
             tdata = GeomVertexWriter(gvd, InternalName.get_transform_blend())
 
+            if not tdata.has_column():
+                continue
+
             jointdata = self.read_vert_data(gvd, InternalName.get_transform_index())
             weightdata = self.read_vert_data(gvd, InternalName.get_transform_weight())
 
@@ -1413,7 +1429,6 @@ class Converter():
                 node = PointLight(lightname)
             elif ltype == 'directional':
                 node = DirectionalLight(lightname)
-                node.set_direction((0, 0, -1))
             elif ltype == 'spot':
                 node = Spotlight(lightname)
             else:
